<?php


namespace Chuckpac\Weather;

use GuzzleHttp\Client;
use Chuckpac\Weather\Exceptions\HttpException;
use Chuckpac\Weather\Exceptions\InvalidArgumentException;

class Weather
{
    /**
     * GaoDe Weather Api key
     * @var String
     */
    protected $key;

    /**
     * guzzle client params
     * @var array
     */
    protected $guzzleOptions = [];

    /**
     * Weather constructor.
     * @param string $key
     */
    public function __construct(string $key)
    {
        $this->key = $key;
    }

    /**
     * get http client object
     * @return Client
     */
    public function getHttpClient()
    {
        return new Client($this->guzzleOptions);
    }

    /**
     * set guzzle options
     * @param array $options
     */
    public function setGuzzleOptions(array $options)
    {
        $this->guzzleOptions = $options;
    }

    /**
     * get weather info
     * @param $city
     * @param string $type
     * @param string $format
     * @return mixed|string
     * @throws \GuzzleHttp\Exception\GuzzleException
     */
    public function getWeather($city,$type = 'base',$format = 'json')
    {
        $url = 'https://restapi.amap.com/v3/weather/weatherInfo';

        if(!\in_array(\strtolower($format),['json','xml'])){
            throw new InvalidArgumentException('Invalid response format: '.$format);
        }

        if(!\in_array(\strtolower($type),['base','all'])){
            throw new InvalidArgumentException('Invalid type value(base/all): '.$type);
        }

        $query = array_filter([
            'key' => $this->key,
            'city' => $city,
            'output' => $format,
            'extensions' =>  $type,
        ]);

        try {
            $response = $this->getHttpClient()->get($url, [
                'query' => $query,
            ])->getBody()->getContents();
        }catch(\Exception $e){
            throw new HttpException($e->getMessage(),$e->getCode(),$e);
        }
        /**
         * json_decode true返回数组 false返回对象
         */
        return 'json' === $format?\json_decode($response,true):$response;
    }

}